view — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# view

Functionality common to TableViews and FormViews

class `camelot.view.controls.view.` `AbstractView`

  A string used to format the title of the view :: title_format = ‘Movie rental overview’

  `header_widget`

  The widget class to be used as a header in the table view:

  header_widget = None

  `change_title`(new_title)

    Will emit the title_changed_signal

  `refresh`()

    Refresh the data in the current view

class `camelot.view.controls.view.` `TabView`(parent, views=[], admin=None)

  Class to combine multiple views in Tabs and let them behave as one view. This class can be used when defining custom create_table_view methods on an ObjectAdmin class to group multiple table views together in one view.

  `refresh`()

    Refresh the data in the current view

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus